@@ -57,7 +57,7 @@ import aptsources.distro
 import softwareproperties
 
 from .AptAuth import AptAuth
-from aptsources.sourceslist import (SourcesList, SourceEntry)
+from aptsources.sourceslist import (SourcesList, SourceEntry, Deb822SourceEntry)
 from softwareproperties.shortcuthandler import InvalidShortcutException
 from softwareproperties.shortcuts import shortcut_handler
 
@@ -83,7 +83,7 @@ class SoftwareProperties(object):
     RELEASE_UPGRADES_NEVER  : 'never',
   }
 
-  def __init__(self, datadir=None, options=None, rootdir="/"):
+  def __init__(self, datadir=None, options=None, rootdir="/", deb822=False):
     """ Provides the core functionality to configure the used software
         repositories, the corresponding authentication keys and
         update automation """
@@ -99,7 +99,7 @@ class SoftwareProperties(object):
     self.options = options
     self.datadir = datadir
 
-    self.sourceslist = SourcesList()
+    self.sourceslist = SourcesList(deb822=deb822)
     self.distro = aptsources.distro.get_distro()
 
     self.seen_server = []
@@ -458,7 +458,10 @@ class SoftwareProperties(object):
     for (index, entry) in enumerate(self.sourceslist.list):
       if str(entry) == old_entry:
         file = self.sourceslist.list[index].file
-        self.sourceslist.list[index] = SourceEntry(new_entry, file)
+        if isinstance(entry, Deb822SourceEntry):
+            self.sourceslist.list[index] = Deb822SourceEntry(new_entry, file)
+        else:
+            self.sourceslist.list[index] = SourceEntry(new_entry, file)
         self.set_modified_sourceslist()
         return True
     return False
